@@ -39,8 +39,6 @@ class TestServiceDocumenter(BaseDocsTest):
             '*********',
             'MyService',
             '*********',
-            '.. contents:: Table of Contents',
-            '   :depth: 2',
             '======',
             'Client',
             '======',
